function wo=OELMCF(X,Y,W,NetDef,r)
% Optimized Extreme Leaning Machine (Coast Function)
% 
% Usage        - wo=OELMCF(X,Y,W,NetDef,r)
%
% Input:
% X            - Input matrix (Number of inputs x Number of samples)
% Y            - Output vector (1 x Number os samples)
% W            - Input weights matrix (Number of hidden neurons x Number of Input +1)
% NetDef       - Network configuration:
%                       The activation functions must be either linear or logsig. The network
%                       architecture is defined by the matrix 'NetDef' consisting of two
%                       rows. The first row specifies the hidden layer while the second
%                       specifies the output layer.
%
%                       E.g.,    NetDef = ['LSSSS'
%                                         'L----']
%
%                      (L = Linear, S = logsig)
%
% r            - Tikhonov's regularization parameter
% Output:
% wo           - Output weights
%
    %%%%    Author:    Tiago Matias
    %%%%    Institute of Systems and Robotics, Coimbra, Portugal
    %%%%    EMAIL:      tmatias@isr.uc.pt
    %%%%    WEBSITE:    http://www.isr.uc.pt/~tmatias/
    %%%%    DATE:       July 2013
[~,N] = size(Y);
L_hidden = find(NetDef(1,:)=='L')';   % Location of linear hidden units
H_hidden = find(NetDef(1,:)=='S')';   % Location of logsig hidden units
[hidden,~] = size(W);
y1       = zeros(hidden,N);

% ---  Compute network output ---
h1 = W*[X;ones(1,N)];
y1(H_hidden,:) = logsig(h1(H_hidden,:));
y1(L_hidden,:) = h1(L_hidden,:);

theta=(y1*y1'+r*eye(size(y1*y1',1)))\y1;

wo=[theta*Y']';

function t=logsig(x)
t= 1 ./ (1 + exp(-1*x));
